@@ -94,7 +94,7 @@ Line2P.prototype.setState = function(state) {
 };
 
 Line2P.prototype.showUiOptions = function(resume, restoreFromSettings) {
-    Draw.prototype.showUiOptions.call(this, resume, restoreFromSettings);
+    Line.prototype.showUiOptions.call(this, resume, restoreFromSettings);
 
 //    var optionsToolBar = EAction.getOptionsToolBar();
 //    var w = optionsToolBar.findChild("Restrict");
@@ -105,6 +105,8 @@ Line2P.prototype.showUiOptions = function(resume, restoreFromSettings) {
 };
 
 Line2P.prototype.initUiOptions = function(resume, optionsToolBar) {
+    Line.prototype.initUiOptions.call(this, resume, optionsToolBar);
+
     var leLength = optionsToolBar.findChild("Length");
     var cbLength = optionsToolBar.findChild("UseLength");
     var leAngle = optionsToolBar.findChild("Angle");
@@ -125,15 +127,23 @@ Line2P.prototype.initUiOptions = function(resume, optionsToolBar) {
         //if (!isNull(cbLength)) cbLength.checked = false;
         //if (!isNull(cbAngle)) cbAngle.checked = false;
 
+        var self = this;
         if (!isNull(leLength)) {
             leLength.textEdited.connect(function() {
+                // prevent selection and overwriting of text when typing numbers:
+                cbLength.blockSignals(true);
                 cbLength.checked = true;
+                self.useLength = true;
+                cbLength.blockSignals(false);
             });
         }
 
         if (!isNull(leAngle)) {
             leAngle.textEdited.connect(function() {
+                cbAngle.blockSignals(true);
                 cbAngle.checked = true;
+                self.useAngle = true;
+                cbAngle.blockSignals(false);
             });
         }
     }
@@ -297,10 +307,11 @@ Line2P.prototype.slotClose = function() {
     }
 
     if (this.pointList.length >= 3) {
-        this.point2 = this.pointList[0];
-        this.getDocumentInterface().applyOperation(this.getOperation(false));
-        this.pointList.push(this.point2);
         var di = this.getDocumentInterface();
+        this.point2 = this.pointList[0];
+        var e = this.createLineEntity(this.getDocument(), this.point1, this.point2);
+        di.applyOperation(new RAddObjectOperation(e, this.getToolTitle()));
+        this.pointList.push(this.point2);
         di.setRelativeZero(this.point2);
         this.setState(Line2P.State.SettingFirstPoint);
     }
